Message

Struct Message 

pub struct Message<T> {
    pub topic: String,
    pub payload: T,
    pub offset: Option<i64>,
    pub partition: Option<i32>,
}
A streaming message wrapping a typed payload with topic and offset metadata.

Fields

topic: String

Topic from which the message was received or to which it will be sent.

payload: T

Typed message payload.

offset: Option<i64>

Backend offset, when provided by the streaming provider.

partition: Option<i32>

Backend partition, when provided by the streaming provider.

Implementations

Source

impl<T> Message<T>

pub fn new(topic: impl Into<String>, payload: T) -> Self

Create a message with topic and payload metadata.

pub fn with_offset(self, offset: i64) -> Self

Attach a backend offset to the message.

pub fn with_partition(self, partition: i32) -> Self

Attach a backend partition to the message.