pub struct Message<T> {
pub topic: String,
pub payload: T,
pub offset: Option<i64>,
pub partition: Option<i32>,
}Expand description
A streaming message wrapping a typed payload with topic and offset metadata.
Fields
topic: StringTopic from which the message was received or to which it will be sent.
payload: TTyped message payload.
offset: Option<i64>Backend offset, when provided by the streaming provider.
partition: Option<i32>Backend partition, when provided by the streaming provider.
Implementations
Sourceimpl<T> Message<T>
impl<T> Message<T>
Sourcepub fn new(topic: impl Into<String>, payload: T) -> Self
pub fn new(topic: impl Into<String>, payload: T) -> Self
Create a message with topic and payload metadata.
Sourcepub fn with_offset(self, offset: i64) -> Self
pub fn with_offset(self, offset: i64) -> Self
Attach a backend offset to the message.
Sourcepub fn with_partition(self, partition: i32) -> Self
pub fn with_partition(self, partition: i32) -> Self
Attach a backend partition to the message.